#include "scene.h"



Scene::Scene(      )
{
    root = new SceneNode(this);
}

int Scene::simpleScene()
{
    addCube();
    moveActive(QVector3D(4,0,0));

    addSphere();
    moveActive(QVector3D(1.5,0,0));

    addCylinder();
    moveActive(QVector3D(0,1.5,-1.5));

    addTorus();
    moveActive(QVector3D(0,0,-3));

    addCone();
    moveActive(QVector3D(0,-1.5,-1.5));

    return active->getID();

}

ScenePrimitive *Scene::addCube()
{
    float color[] = {0.0,0.0,1.0};
    ScenePrimitive *primitive = new ScenePrimitive(PrimitiveType::Quader,tesselation,root);
    primitive->setMaterial(color);
    root->add(primitive);
    active = primitive;
    emit activChanged();
    return primitive;
}

ScenePrimitive* Scene::addSphere()
{
    float color[] = {0.0,1.0,0.0};
    ScenePrimitive *primitive = new ScenePrimitive(PrimitiveType::Sphere,tesselation,root);
    primitive->setMaterial(color);
    root->add(primitive);
    active = primitive;
    emit activChanged();
    return primitive;
}

ScenePrimitive* Scene::addCylinder()
{
    float color[] = {1.0,0.0,0.0};
    ScenePrimitive *primitive = new ScenePrimitive(PrimitiveType::Cylinder,tesselation,root);
    primitive->setMaterial(color);
    root->add(primitive);
    active = primitive;
    emit activChanged();
    return primitive;
}

ScenePrimitive* Scene::addTorus()
{
    float color[] = {1.0,0.0,1.0};
    ScenePrimitive *primitive = new ScenePrimitive(PrimitiveType::Torus,tesselation,root);
    primitive->setMaterial(color);
    root->add(primitive);
    active = primitive;
    emit activChanged();
    return primitive;
}

ScenePrimitive* Scene::addCone()
{
    float color[] = {0.0,1.0,1.0};
    ScenePrimitive *primitive = new ScenePrimitive(PrimitiveType::Cone,tesselation,root);
    primitive->setMaterial(color);
    root->add(primitive);
    active = primitive;
    emit activChanged();
    return primitive;
}


void Scene::setTesselation(int tesselation)
{
    this->tesselation = tesselation;
}

SceneObject *Scene::setActive(int id){
    active = root->find(id);
    emit activChanged();
    return active;
}

SceneObject *Scene::getActive(){
    return active;
}

void Scene::draw()
{
    root->draw();
}

SceneNode *Scene::getRoot()
{
    return root;
}

void Scene::moveActive(QVector3D dir)
{
    if(active != NULL)
        active->move(dir);

}

void Scene::rotateActive(QQuaternion rot)
{
    if(active != NULL)
        active->rotate(rot);
}


